pub enum PaymentMethod {
Onchain(Onchain),
Invoice(Invoice),
Offer(OfferWithAmount),
LnurlPayRequest(LnurlPayRequest),
}Expand description
A single “payment method” – each kind here should correspond with a single linear payment flow for a user, where there are no other alternate methods.
For example, a Unified BTC QR code contains a single BIP321 URI, which may contain multiple discrete payment methods (an onchain address, a BOLT11 invoice, a BOLT12 offer).
Variants
Implementations
Sourceimpl PaymentMethod
impl PaymentMethod
pub fn is_onchain(&self) -> bool
pub fn is_invoice(&self) -> bool
pub fn is_offer(&self) -> bool
pub fn supports_network(&self, network: Network) -> bool