pub struct OfferWithAmount {
pub offer: Offer,
pub bip321_amount: Option<Amount>,
}Expand description
An offer payment method with optional amount from a BIP321 URI.
Fields
offer: Offerbip321_amount: Option<Amount>Amount from BIP321 URI. Used when the offer is amount-less to pre-fill an amount in the UI.
Implementations
Sourceimpl OfferWithAmount
impl OfferWithAmount
Sourcepub fn prompt_amount(&self) -> Option<Amount>
pub fn prompt_amount(&self) -> Option<Amount>
The amount that we should prompt the user with. Returns the offer’s embedded amount if present, otherwise uses the BIP321 URI amount.
pub fn supports_network(&self, network: Network) -> bool
pub fn no_bip321_amount(offer: Offer) -> OfferWithAmount